==> ejc-sddjsorg-impl-3.0.0-20211104.063347-142-sources.jar: com/ejianc/business/production/bean/UndertakerEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-承接方
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_undertaker")
public class UndertakerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="in_out_captail")
    private String inOutCaptail; // 内/外部承接方
    @TableField(value="undertaker_name_id")
    private Long undertakerNameId; // 承接方名称Id
    @TableField(value="undertaker_name")
    private String undertakerName; // 承接方名称
    @TableField(value="undertaker_nature")
    private String undertakerNature; // 承接方性质
    @TableField(value="undertaker_regulatory_bodies")
    private String undertakerRegulatoryBodies; // 承接方所属国资监管机构
    @TableField(value="undertaker_equity_ratio")
    private java.math.BigDecimal undertakerEquityRatio; // 司法处置股权比例(%)
    
    
    

    /**
     * 单据名称
     */
    public String getName() {
        return name;
    }

    /**
     * 单据名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 内/外部承接方
     */
    public String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部承接方
     */
    public void setInOutCaptail(String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 承接方名称Id
     */
    public Long getUndertakerNameId() {
        return undertakerNameId;
    }

    /**
     * 承接方名称Id
     */
    public void setUndertakerNameId(Long undertakerNameId) {
        this.undertakerNameId = undertakerNameId;
    }
    /**
     * 承接方名称
     */
    public String getUndertakerName() {
        return undertakerName;
    }

    /**
     * 承接方名称
     */
    public void setUndertakerName(String undertakerName) {
        this.undertakerName = undertakerName;
    }
    /**
     * 承接方性质
     */
    public String getUndertakerNature() {
        return undertakerNature;
    }

    /**
     * 承接方性质
     */
    public void setUndertakerNature(String undertakerNature) {
        this.undertakerNature = undertakerNature;
    }
    /**
     * 承接方所属国资监管机构
     */
    public String getUndertakerRegulatoryBodies() {
        return undertakerRegulatoryBodies;
    }

    /**
     * 承接方所属国资监管机构
     */
    public void setUndertakerRegulatoryBodies(String undertakerRegulatoryBodies) {
        this.undertakerRegulatoryBodies = undertakerRegulatoryBodies;
    }
    /**
     * 司法处置股权比例(%)
     */
    public java.math.BigDecimal getUndertakerEquityRatio() {
        return undertakerEquityRatio;
    }

    /**
     * 司法处置股权比例(%)
     */
    public void setUndertakerEquityRatio(java.math.BigDecimal undertakerEquityRatio) {
        this.undertakerEquityRatio = undertakerEquityRatio;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211210.104338-148-sources.jar: com/ejianc/business/production/bean/UndertakerEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-承接方
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_undertaker")
public class UndertakerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="in_out_captail")
    private String inOutCaptail; // 内/外部承接方
    @TableField(value="undertaker_name_id")
    private Long undertakerNameId; // 承接方名称Id
    @TableField(value="undertaker_name")
    private String undertakerName; // 承接方名称
    @TableField(value="undertaker_nature")
    private String undertakerNature; // 承接方性质
    @TableField(value="undertaker_regulatory_bodies")
    private String undertakerRegulatoryBodies; // 承接方所属国资监管机构
    @TableField(value="undertaker_equity_ratio")
    private java.math.BigDecimal undertakerEquityRatio; // 司法处置股权比例(%)

    @TableField(value="pid")
    private Long pid; //父类id
    

    /**
     * 单据名称
     */
    public String getName() {
        return name;
    }

    /**
     * 单据名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 内/外部承接方
     */
    public String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部承接方
     */
    public void setInOutCaptail(String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 承接方名称Id
     */
    public Long getUndertakerNameId() {
        return undertakerNameId;
    }

    /**
     * 承接方名称Id
     */
    public void setUndertakerNameId(Long undertakerNameId) {
        this.undertakerNameId = undertakerNameId;
    }
    /**
     * 承接方名称
     */
    public String getUndertakerName() {
        return undertakerName;
    }

    /**
     * 承接方名称
     */
    public void setUndertakerName(String undertakerName) {
        this.undertakerName = undertakerName;
    }
    /**
     * 承接方性质
     */
    public String getUndertakerNature() {
        return undertakerNature;
    }

    /**
     * 承接方性质
     */
    public void setUndertakerNature(String undertakerNature) {
        this.undertakerNature = undertakerNature;
    }
    /**
     * 承接方所属国资监管机构
     */
    public String getUndertakerRegulatoryBodies() {
        return undertakerRegulatoryBodies;
    }

    /**
     * 承接方所属国资监管机构
     */
    public void setUndertakerRegulatoryBodies(String undertakerRegulatoryBodies) {
        this.undertakerRegulatoryBodies = undertakerRegulatoryBodies;
    }
    /**
     * 司法处置股权比例(%)
     */
    public java.math.BigDecimal getUndertakerEquityRatio() {
        return undertakerEquityRatio;
    }

    /**
     * 司法处置股权比例(%)
     */
    public void setUndertakerEquityRatio(java.math.BigDecimal undertakerEquityRatio) {
        this.undertakerEquityRatio = undertakerEquityRatio;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}
